pysmad.bodies
================

.. toctree::
   :maxdepth: 2

   pysmad.bodies.artificial
   pysmad.bodies.celestial
   pysmad.bodies.terrestrial

.. automodule:: pysmad.bodies
   :members:
   :undoc-members:
   :show-inheritance:
